@@ -1,4 +1,5 @@
 import json
+import os.path as osp
 
 
 def load_json(file_path):
@@ -14,6 +15,8 @@ def load_json(file_path):
     data : dict
         loaded json data
     """
+    if not osp.exists(str(file_path)):
+        raise OSError('{} not exists'.format(str(file_path)))
     with open(str(file_path), "r") as f:
         return json.load(f)
 
